==> eclipse-orion-1.0-linux.gtk.x86_64.zip: web/orion/sites/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8

define({
	"Name:": "Name:",
	"Path":"Path",
	"Mount at (server path)": "Mount at (server path)",
	"Mappings:": "Mappings:",
	"Hostname hint:": "Hostname hint:",
	"Status:": "Status:",
	"Not a valid name": "Not a valid name",
	"Not a valid hostname": "Not a valid hostname",
	"Convert to Self-Hosting": "Convert to Self-Hosting",
	"Enable the site configuration to launch an Orion server running your local client code": "Enable the site configuration to launch an Orion server running your local client code",
	"Save": "Save",
	"Save the site configuration": "Save the site configuration",
	"Choose folder&#8230;": "Choose folder&#8230;",
	"Choose Orion Source Folder": "Choose Orion Source Folder",
	"SelectRepoSourceFolder": "Select the folder where you checked out the ${0} repository:",
	"Loading...": "Loading...",
	"Add": "Add",
	"Add a directory mapping to the site configuration": "Add a directory mapping to the site configuration",
	"There are unsaved changes. Do you still want to navigate away?": "There are unsaved changes. Do you still want to navigate away?",
	"There are unsaved changes.": "There are unsaved changes.",
	"Service method missing: ": "Service method missing: ",
	"No Matching SiteService for ": "No Matching SiteService for ",
	"Create": "Create",
	"Create a new site configuration": "Create a new site configuration",
	"Edit": "Edit",
	"Edit the site configuration": "Edit the site configuration",
	"Delete": "Delete",
	"Delete the site configuration": "Delete the site configuration",
	"ConfirmDeleteSingle": "Are you sure you want to delete the site configuration '${0}'?",
	"ConfirmDeleteMultiple": "Are you sure you want to delete these ${0} site configurations?",
	"ViewOnSiteTitle": "View on Site",
	"ViewOnSiteCaption": "Choose a site configuration to view '${0}' on.",
	"Add to site": "Add to site",
	"Add the file to this site": "Add the file to this site",
	"View": "View",
	"View the file on the site": "View the file on the site",
	"Started": "Started at",
	"Unknown": "Unknown",
	"Name": "Name",
	"Actions": "Actions",
	"Status": "Status",
	"URL": "URL",
	"New Site": "New Site",
	"WorkspaceFile": "Workspace file: ${0}",
	"WorkspaceFolder": "Workspace folder: ${0}",
	"WorkspaceResourceNotFound": "Workspace resource not found: ${0}",
	"ExternalLinkTo": "External link to ${0}",
	"Move Up": "Move Up",
	"Move Down": "Move Down",
	"HostHint": "HostHint",
	"Start": "Start",
	"Stop": "Stop",
	"Optional; used to determine the URL where a started site can be accessed." : "Optional; used to determine the URL where a started site can be accessed.",
	"Changes you make here won't affect the running site." : "Changes you make here won't affect the running site.",
	"Stopped" : "Stopped",
	"Started at " : "Started at ",
	"EnterPortNumber": "Enter the HTTP port number that the Orion server is running on (default is ${0}):"
});

==> eclipse-orion-2.0-linux.gtk.x86_64.zip: web/orion/sites/nls/root/messages.js <==
/*******************************************************************************
 * @license
 * Copyright (c) 2012 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials are made 
 * available under the terms of the Eclipse Public License v1.0 
 * (http://www.eclipse.org/legal/epl-v10.html), and the Eclipse Distribution 
 * License v1.0 (http://www.eclipse.org/org/documents/edl-v10.html). 
 * 
 ******************************************************************************/

//NLS_CHARSET=UTF-8

define({
	"OK": "OK",
	"Name:": "Name:",
	"Path":"Path",
	"Mount at (server path)": "Mount at (server path)",
	"Mappings:": "Mappings:",
	"Hostname hint:": "Hostname hint:",
	"Status:": "Status:",
	"Not a valid name": "Not a valid name",
	"Not a valid hostname": "Not a valid hostname",
	"Convert to Self-Hosting": "Convert to Self-Hosting",
	"Enable the site configuration to launch an Orion server running your local client code": "Enable the site configuration to launch an Orion server running your local client code",
	"Save": "Save",
	"Save the site configuration": "Save the site configuration",
	"Choose folder...": "Choose folder\u2026",
	"Choose Orion Source Folder": "Choose Orion Source Folder",
	"SelectRepoSourceFolder": "Select the folder where you checked out the ${0} repository:",
	"Loading...": "Loading...",
	"Add": "Add",
	"Add a directory mapping to the site configuration": "Add a directory mapping to the site configuration",
	"There are unsaved changes. Do you still want to navigate away?": "There are unsaved changes. Do you still want to navigate away?",
	"There are unsaved changes.": "There are unsaved changes.",
	"Service method missing: ": "Service method missing: ",
	"No Matching SiteService for ": "No Matching SiteService for ",
	"Create": "Create",
	"Create a new site configuration": "Create a new site configuration",
	"Edit": "Edit",
	"Edit the site configuration": "Edit the site configuration",
	"Delete": "Delete",
	"Delete the site configuration": "Delete the site configuration",
	"ConfirmDeleteSingle": "Are you sure you want to delete the site configuration '${0}'?",
	"ConfirmDeleteMultiple": "Are you sure you want to delete these ${0} site configurations?",
	"ViewOnSiteTitle": "View on Site",
	"ViewOnSiteCaption": "Choose a site configuration to view '${0}' on.",
	"Add to site": "Add to site",
	"Add the file to this site": "Add the file to this site",
	"View": "View",
	"View the file on the site": "View the file on the site",
	"Started": "Started at",
	"Unknown": "Unknown",
	"Name": "Name",
	"Actions": "Actions",
	"Status": "Status",
	"URL": "URL",
	"New Site": "New Site",
	"WorkspaceFile": "Workspace file: ${0}",
	"WorkspaceFolder": "Workspace folder: ${0}",
	"WorkspaceResourceNotFound": "Workspace resource not found: ${0}",
	"ExternalLinkTo": "External link to ${0}",
	"Move Up": "Move Up",
	"Move Down": "Move Down",
	"HostHint": "HostHint",
	"Start": "Start",
	"Stop": "Stop",
	"Optional; used to determine the URL where a started site can be accessed." : "Optional; used to determine the URL where a started site can be accessed.",
	"Changes you make here won't affect the running site." : "Changes you make here won't affect the running site.",
	"Stopped" : "Stopped",
	"Started at " : "Started at ",
	"EnterPortNumber": "Enter the HTTP port number that the Orion server is running on (default is ${0}):",
	"SitesCommandScope": "Sites"
});
